// Darstellung dreier durch Gleichungen beschriebener Ebenen im R3
// A. Filler, Humboldt-Universitaet zu Berlin
// Dezember 2001 / Januar 2002
// ---------------------------------------------------------------
#version 3.5;                         // bentigte POV-Ray-Version
background { color rgb <1, 1, 1> }    // Hintergrundfarbe (wei)
#include "gaussalg.inc"                // Makropaket zu Vektoren, Koord-system, Ebenen usw.
// -----------------------------------------------------------
#declare intervall = 10 ;             // Diese Variable legt den Bildausschnitt der gesamten Szene fest.
// ---------------------------------------------------------------
// Definition der Kamera und der Lichtquellen

#declare winkel =  - 60  - 1.2*clock ;       // Winkel der Kamera zur x-Achse (in Grad)
camera { orthographic
         location  <60*intervall*cos(winkel*pi/180), 20*intervall, 60*intervall*sin(winkel*pi/180)>
         right x*4/3*2.7*intervall   up y*2.7*intervall
         look_at   <0.0, -intervall/10,  0.0> 
}
light_source { <2.5*intervall, 2*intervall, -5*intervall>  color rgb <1, 1, 1> }
light_source { <0,10*intervall,2*intervall>  color rgb <1, 1, 1> }
// ---------------------------------------------------------------
// Eingabe der Koeeffizienten des Gleichungssystems
// ---------------------------------------------------------------
#declare Z11 = <3/2 ,  4 ,  -2 > ;  // Koeffizienten der 1. Gleichung
#declare Z12 = <2   , -2 , -9/2> ;  // Koeffizienten der 2. Gleichung
#declare Z13 = <1   , -3 ,  1  > ;  // Koeffizienten der 3. Gleichung
#declare b11 =     1 ;              // / Rechte Seite
#declare b12 = - 1/2 ;              // | des
#declare b13 =     2 ;              // \ Gleichungssystems
// ---------------------------------------------------------------
// 1. Schritt des GA:
#declare Z21 = Z11 ;
#declare Z22 = Z12 - Z12.x / Z11.x * Z11 ;
#declare Z23 = Z13 - Z13.x / Z11.x * Z11 ;
#declare b21 = b11  ;
#declare b22 = b12 - Z12.x / Z11.x * b11 ;  
#declare b23 = b13 - Z13.x / Z11.x * b11 ;
// 2. Schritt des GA:
#declare Z31 = Z21 ;
#declare Z32 = Z22 ;
#declare Z33 = Z23 - Z23.y / Z22.y * Z22 ;
#declare b31 = b11 ;
#declare b32 = b22 ;  
#declare b33 = b23 - Z23.y / Z22.y * b22 ;
// 3. Schritt des GA:
#declare Z41 = Z31 ;
#declare Z42 = Z32 - Z32.z * Z33 / Z33.z  ;
#declare Z43 = Z33 ;
#declare b41 = b31 ;
#declare b42 = b32 - Z32.z * b33 / Z33.z  ;  
#declare b43 = b33 ;
// 4. Schritt des GA:
#declare Z51 = Z41  - Z41.z * Z43 / Z43.z  - Z41.y * Z42 / Z42.y  ;
#declare Z52 = Z42 ;
#declare Z53 = Z43 ;
#declare b51 = b41  - Z41.z * b43 / Z43.z  - Z41.y * b42 / Z42.y ;
#declare b52 = b42 ;  
#declare b53 = b43 ;                
// ---------------------------------------------------------------
#declare i = 0  ;        // Gibt an, dass das LGS nach dem i.-ten Schritt des
                         // GA dargestellt werden soll (i = 0 ... 4)
// ---------------------------------------------------------------
// Definition der Oberflcheneigenschaften (Texturen) der Ebenen:
#declare Material_Ebene_blau =  texture{ pigment{rgbf<0.4,0.4,1,0.8>} 
    finish{ ambient 1.0  diffuse 0.8  phong 0  reflection 0.0}    } ;
#declare Material_Ebene_rot =  texture{ pigment{rgbf<1,0.3,0.3,0.8>} 
    finish{ ambient 1.0  diffuse 0.8  phong 0  reflection 0.0}    };
#declare Material_Ebene_gruen =  texture{ pigment{rgbf<0.3,1,0.3,0.8>}
    finish{ ambient 1.0  diffuse 0.8  phong 0  reflection 0.0}    };
// ---------------------------------------------------------------    
// Beschreibung der Ebenen durch "ebenegl (A,B,C,D,textur)" wobei A,B,C,D die 
// Koeffizienten der Ebenengleichung Ax+By+Cz+D=0 sind und "textur" eine Textur beschreibt:
#switch (i)
#case (0)
ebenegl (Z11.x , Z11.y , Z11.z , -b11 , Material_Ebene_blau)
ebenegl (Z12.x , Z12.y , Z12.z , -b12  , Material_Ebene_rot)
ebenegl (Z13.x , Z13.y , Z13.z , -b13  , Material_Ebene_gruen)
#break 
#case (1)
// Nach dem 1. Schritt des GA:
ebenegl (Z21.x , Z21.y , Z21.z , -b21 , Material_Ebene_blau)
ebenegl (Z22.x , Z22.y , Z22.z , -b22  , Material_Ebene_rot)
ebenegl (Z23.x , Z23.y , Z23.z , -b23  , Material_Ebene_gruen)
#break 
#case (2)
// Nach dem 2. Schritt des GA (Dreiecksform):
ebenegl (Z31.x , Z31.y , Z31.z , -b31 , Material_Ebene_blau)
ebenegl (Z32.x , Z32.y , Z32.z , -b32  , Material_Ebene_rot)
ebenegl (Z33.x , Z33.y , Z33.z , -b33  , Material_Ebene_gruen)
#break 
#case (3)
// Nach dem 3. Schritt des GA:
ebenegl (Z41.x , Z41.y , Z41.z , -b41 , Material_Ebene_blau)
ebenegl (Z42.x , Z42.y , Z42.z , -b42  , Material_Ebene_rot)
ebenegl (Z43.x , Z43.y , Z43.z , -b43  , Material_Ebene_gruen)
#break 
#case (4)
// Nach dem 4. Schritt des GA (Diagonalform):
ebenegl (Z51.x , Z51.y , Z51.z , -b51 , Material_Ebene_blau)
ebenegl (Z52.x , Z52.y , Z52.z , -b52  , Material_Ebene_rot)
ebenegl (Z53.x , Z53.y , Z53.z , -b53  , Material_Ebene_gruen)
#break 
#else
#end 
// ---------------------------------------------------------------
// Einfgen eines Koordinatensystems mit Achsen von -intervall bis intervall
// (definiert in "ana-geo.inc")
// ---------------------------------------------------------------
koordinatensystem (intervall)         
// ---------------------------------------------------------------