// Darstellung der Spaltenvektoren eines LGS im R3
// A. Filler, Humboldt-Universitaet zu Berlin
// Januar 2002
// ---------------------------------------------------------------
#version 3.5;                         // bentigte POV-Ray-Version
background { color rgb <1, 1, 1> }    // Hintergrundfarbe (wei)
#include "golds.inc"   
#include "gaussalg.inc"                // Makropaket zu Vektoren, Koord-system, Ebenen usw.
// ---------------------------------------------------------------
#declare intervall = 5  ;             // Diese Variable legt den Bildausschnitt der gesamten Szene fest.
// ---------------------------------------------------------------
// Definition der Kamera und der Lichtquellen

#declare winkel =  - 60 ;       // Winkel der Kamera zur x-Achse (in Grad)
camera { orthographic
         location  <60*intervall*cos(winkel*pi/180), 20*intervall, 60*intervall*sin(winkel*pi/180)>
         right x*4/3*2.7*intervall   up y*2.7*intervall
         look_at   <0.0, -intervall/10,  0.0> 
}
light_source { <2.5*intervall, 2*intervall, -5*intervall>  color rgb <1, 1, 1> }
light_source { <0,10*intervall,2*intervall>  color rgb <1, 1, 1> }
// ---------------------------------------------------------------
#declare vektortextur = texture { pigment { rgbt<0.3,0.3,0.3,0.5> }
    finish { ambient 0.0 diffuse 0.2 reflection 0.1 brilliance 1 specular 0.4 roughness 0.1 }};
// ---------------------------------------------------------------
// Eingabe der Koeeffizienten des Gleichungssystems
// ---------------------------------------------------------------
#declare Z11 = <3/2 ,  4 ,  -2 > ;  // Koeffizienten der 1. Gleichung
#declare Z12 = <2   , -2 , -9/2> ;  // Koeffizienten der 2. Gleichung
#declare Z13 = <1   , -3 ,  1  > ;  // Koeffizienten der 3. Gleichung
#declare b11 =     1 ;              // / Rechte Seite
#declare b12 = - 1/2 ;              // | des
#declare b13 =     2 ;              // \ Gleichungssystems    
// ---------------------------------------------------------------
// 1. Schritt des GA:
#declare Z21 = Z11 ;
#declare Z22 = Z12 - Z12.x / Z11.x * Z11 ;
#declare Z23 = Z13 - Z13.x / Z11.x * Z11 ;
#declare b21 = b11  ;
#declare b22 = b12 - Z12.x / Z11.x * b11 ;  
#declare b23 = b13 - Z13.x / Z11.x * b11 ;
// 2. Schritt des GA:
#declare Z31 = Z21 ;
#declare Z32 = Z22 ;
#declare Z33 = Z23 - Z23.y / Z22.y * Z22 ;
#declare b31 = b11 ;
#declare b32 = b22 ;  
#declare b33 = b23 - Z23.y / Z22.y * b22 ;
// 3. Schritt des GA:
#declare Z41 = Z31 ;
#declare Z42 = Z32 - Z32.z * Z33 / Z33.z  ;
#declare Z43 = Z33 ;
#declare b41 = b31 ;
#declare b42 = b32 - Z32.z * b33 / Z33.z  ;  
#declare b43 = b33 ;
// 4. Schritt des GA:
#declare Z51 = Z41  - Z41.z * Z43 / Z43.z  - Z41.y * Z42 / Z42.y  ;
#declare Z52 = Z42 ;
#declare Z53 = Z43 ;
#declare b51 = b41  - Z41.z * b43 / Z43.z  - Z41.y * b42 / Z42.y ;
#declare b52 = b42 ;  
#declare b53 = b43 ;           
// Lsung des Gleichungssystems
#declare LV = <  b51 / Z51.x  , b52 / Z52.y , b53 / Z53.z > ;  // Lsungsvektor des LGS 
// ---------------------------------------------------------------
#declare i = 0  ;         // Gibt an, dass das LGS nach dem i.-ten Schritt des 
                              // GA dargestellt werden soll  (i = 0 ... 4)
// ---------------------------------------------------------------
#switch (i)
#case (0)
#declare V1 = < Z11.x ,  Z12.x   ,  Z13.x >  ; // Spaltenvektor 1 des LGS
#declare V2 = < Z11.y ,  Z12.y   ,  Z13.y >  ; // Spaltenvektor 2 des LGS 
#declare V3 = < Z11.z ,  Z12.z   ,  Z13.z >  ; // Spaltenvektor 3 des LGS  
#declare VR = < b11 , b12 , b13 >  ; // Spaltenvektor - Rechte Seite des LGS 
#break 
#case (1)
// Nach dem 1. Schritt des GA:
#declare V1 = < Z21.x ,  Z22.x   ,  Z23.x >  ; // Spaltenvektor 1 des LGS
#declare V2 = < Z21.y ,  Z22.y   ,  Z23.y >  ; // Spaltenvektor 2 des LGS 
#declare V3 = < Z21.z ,  Z22.z   ,  Z23.z >  ; // Spaltenvektor 3 des LGS  
#declare VR = < b21 , b22 , b23 >  ; // Spaltenvektor - Rechte Seite des LGS
#break 
#case (2)
// Nach dem 2. Schritt des GA (Dreiecksform):
#declare V1 = < Z31.x ,  Z32.x   ,  Z33.x >  ; // Spaltenvektor 1 des LGS
#declare V2 = < Z31.y ,  Z32.y   ,  Z33.y >  ; // Spaltenvektor 2 des LGS 
#declare V3 = < Z31.z ,  Z32.z   ,  Z33.z >  ; // Spaltenvektor 3 des LGS  
#declare VR = < b31 , b32 , b33 >  ; // Spaltenvektor - Rechte Seite des LGS 
#break 
#case (3)
// Nach dem 3. Schritt des GA:
#declare V1 = < Z41.x ,  Z42.x   ,  Z43.x >  ; // Spaltenvektor 1 des LGS
#declare V2 = < Z41.y ,  Z42.y   ,  Z43.y >  ; // Spaltenvektor 2 des LGS 
#declare V3 = < Z41.z ,  Z42.z   ,  Z43.z >  ; // Spaltenvektor 3 des LGS  
#declare VR = < b41 , b42 , b43 >  ; // Spaltenvektor - Rechte Seite des LGS    
#break 
#case (4)
// Nach dem 4. Schritt des GA (Diagonalform):
#declare V1 = < Z51.x ,  Z52.x   ,  Z53.x >  ; // Spaltenvektor 1 des LGS
#declare V2 = < Z51.y ,  Z52.y   ,  Z53.y >  ; // Spaltenvektor 2 des LGS 
#declare V3 = < Z51.z ,  Z52.z   ,  Z53.z >  ; // Spaltenvektor 3 des LGS  
#declare VR = < b51 , b52 , b53 >  ; // Spaltenvektor - Rechte Seite des LGS    
#break 
#else
#end 
// --------------------------------------------------------------- 
// Zeichnen der Spaltenvektoren und der Kanten des Parallelepipeds
// (mit den oben eingegebenen Koeffizienten)
// --------------------------------------------------------------- 
ortsvektor (<VR.x,VR.y,VR.z>, T_Gold_1D)
ortsvektor (<V1.x,V1.y,V1.z>, vektortextur)
ortsvektor (<V2.x,V2.y,V2.z>, vektortextur)
ortsvektor (<V3.x,V3.y,V3.z>, vektortextur)

#declare Material_Strecke_blau =  texture{ pigment{rgb<0.1,0.1,1>} finish{ambient 0.2 diffuse 0.3 phong 0.5 reflection 0.4} }
strecke (<0,0,0>, LV.x*<V1.x,V1.y,V1.z> , Material_Strecke_blau)
strecke (<0,0,0>, LV.y*<V2.x,V2.y,V2.z> , Material_Strecke_blau)
strecke (<0,0,0>, LV.z*<V3.x,V3.y,V3.z> , Material_Strecke_blau)
strecke (LV.x*<V1.x,V1.y,V1.z> , LV.x*<V1.x,V1.y,V1.z> + LV.y*<V2.x,V2.y,V2.z> , Material_Strecke_blau) 
strecke (LV.x*<V1.x,V1.y,V1.z> , LV.x*<V1.x,V1.y,V1.z> + LV.z*<V3.x,V3.y,V3.z> , Material_Strecke_blau)
strecke (LV.y*<V2.x,V2.y,V2.z> , LV.y*<V2.x,V2.y,V2.z> + LV.x*<V1.x,V1.y,V1.z> , Material_Strecke_blau)
strecke (LV.y*<V2.x,V2.y,V2.z> , LV.y*<V2.x,V2.y,V2.z> + LV.z*<V3.x,V3.y,V3.z> , Material_Strecke_blau)
strecke (LV.z*<V3.x,V3.y,V3.z> , LV.z*<V3.x,V3.y,V3.z> + LV.y*<V2.x,V2.y,V2.z> , Material_Strecke_blau)
strecke (LV.z*<V3.x,V3.y,V3.z> , LV.z*<V3.x,V3.y,V3.z> + LV.x*<V1.x,V1.y,V1.z> , Material_Strecke_blau) 
strecke (LV.x*<V1.x,V1.y,V1.z> + LV.y*<V2.x,V2.y,V2.z> , LV.x*<V1.x,V1.y,V1.z> + LV.y*<V2.x,V2.y,V2.z>  + LV.z*<V3.x,V3.y,V3.z> , Material_Strecke_blau)    
strecke (LV.y*<V2.x,V2.y,V2.z> + LV.z*<V3.x,V3.y,V3.z> , LV.x*<V1.x,V1.y,V1.z> + LV.y*<V2.x,V2.y,V2.z>  + LV.z*<V3.x,V3.y,V3.z> , Material_Strecke_blau)
strecke (LV.x*<V1.x,V1.y,V1.z> + LV.z*<V3.x,V3.y,V3.z> , LV.x*<V1.x,V1.y,V1.z> + LV.y*<V2.x,V2.y,V2.z>  + LV.z*<V3.x,V3.y,V3.z> , Material_Strecke_blau)  
// ---------------------------------------------------------------
// Einfgen eines Koordinatensystems mit Achsen von -intervall bis intervall
// (definiert in "ana-geo.inc")
// ---------------------------------------------------------------
koordinatensystem (intervall)         
// ---------------------------------------------------------------                                   